==> epiphany-0.7.3.tar.gz: epiphany-0.7.3/lib/widgets/ephy-tree-model-sort.h <==
/*  Copyright (C) 2002 Olivier Martin <omartin@ifrance.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: ephy-tree-model-sort.h,v 1.2 2003/03/25 19:53:56 mpeseng Exp $
 */

#ifndef EPHY_TREE_MODEL_SORT_H
#define EPHY_TREE_MODEL_SORT_H

#include <glib-object.h>

#include <gtk/gtktreemodelsort.h>

G_BEGIN_DECLS

#define EPHY_TYPE_TREE_MODEL_SORT         (ephy_tree_model_sort_get_type ())
#define EPHY_TREE_MODEL_SORT(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_TREE_MODEL_SORT, EphyTreeModelSort))
#define EPHY_TREE_MODEL_SORT_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_TREE_MODEL_SORT, EphyTreeModelSortClass))
#define EPHY_IS_TREE_MODEL_SORT(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_TREE_MODEL_SORT))
#define EPHY_IS_TREE_MODEL_SORT_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_TREE_MODEL_SORT))
#define EPHY_TREE_MODEL_SORT_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_TREE_MODEL_SORT, EphyTreeModelSortClass))

typedef struct EphyTreeModelSortPrivate EphyTreeModelSortPrivate;

typedef struct
{
	GtkTreeModelSort parent;

	EphyTreeModelSortPrivate *priv;
} EphyTreeModelSort;

typedef struct
{
	GtkTreeModelSortClass parent_class;

	void (*node_from_iter) (EphyTreeModelSort *model, GtkTreeIter *iter, void **node);
} EphyTreeModelSortClass;

GType		ephy_tree_model_sort_get_type		(void);

GtkTreeModel   *ephy_tree_model_sort_new		(GtkTreeModel *child_model);

void		ephy_tree_model_sort_set_drag_property	(EphyTreeModelSort *ms,
							 guint id);

G_END_DECLS

#endif /* EPHY_TREE_MODEL_SORT_H */

==> epiphany-1.5.4.tar.gz: epiphany-1.5.4/lib/widgets/ephy-tree-model-sort.h <==
/*  Copyright (C) 2002 Olivier Martin <omartin@ifrance.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: ephy-tree-model-sort.h,v 1.5 2005/01/08 19:41:47 chpe Exp $
 */

#ifndef EPHY_TREE_MODEL_SORT_H
#define EPHY_TREE_MODEL_SORT_H

#include <glib-object.h>

#include <gtk/gtktreemodelsort.h>

G_BEGIN_DECLS

#define EPHY_TYPE_TREE_MODEL_SORT         (ephy_tree_model_sort_get_type ())
#define EPHY_TREE_MODEL_SORT(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_TREE_MODEL_SORT, EphyTreeModelSort))
#define EPHY_TREE_MODEL_SORT_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_TREE_MODEL_SORT, EphyTreeModelSortClass))
#define EPHY_IS_TREE_MODEL_SORT(o)        (G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_TREE_MODEL_SORT))
#define EPHY_IS_TREE_MODEL_SORT_CLASS(k)  (G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_TREE_MODEL_SORT))
#define EPHY_TREE_MODEL_SORT_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_TREE_MODEL_SORT, EphyTreeModelSortClass))

typedef struct _EphyTreeModelSortPrivate EphyTreeModelSortPrivate;

typedef struct
{
	GtkTreeModelSort parent;

	/*< private >*/
	EphyTreeModelSortPrivate *priv;
} EphyTreeModelSort;

typedef struct
{
	GtkTreeModelSortClass parent_class;

	void (*node_from_iter) (EphyTreeModelSort *model, GtkTreeIter *iter, void **node);
} EphyTreeModelSortClass;

GType		ephy_tree_model_sort_get_type		(void);

GtkTreeModel   *ephy_tree_model_sort_new		(GtkTreeModel *child_model);

void		ephy_tree_model_sort_set_column_id	(EphyTreeModelSort *ms,
							 int id);

G_END_DECLS

#endif /* EPHY_TREE_MODEL_SORT_H */
